/*
 * file WorkspaceProvider.java
 *
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM
 *
 * (c) Copyright IBM Corporation 2004, 2008.  All Rights Reserved. 
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or  
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp. 
 */
package javax.wvcm;


/**
 * A WVCM workspace provider.
 *
 * A WVCM workspace provider is a factory for creating new new proxy objects for
 * resources that are members of a workspace. A WVCM workspace provider also can
 * be queried to determine recommended locations for workspaces, both to guide
 * the placement of new workspaces as well as to locate existing resources. Once
 * a workspace is located, the workspace resource can be queried to determine
 * locations for other types of resources.
 * 
 * @since 1.0
 */
public interface WorkspaceProvider extends Provider {

    public static final String IA_ROOT_LOCATION = "com.ibm.rational.wvcm.ROOT_LOCATION"; //$NON-NLS-1$
    public static final String IA_WORKSPACE_PATH = "com.ibm.rational.wvcm.WORKSPACE_LOCATION"; //$NON-NLS-1$
    public static final String IA_CR_HAS_ONE_PARENT = "com.ibm.rational.wvcm.ri.repo.CR_HAS_ONE_PARENT"; //$NON-NLS-1$
    public static final String IA_STREAM_FORGETS_UNBOUND_VERSIONS = "com.ibm.rational.wvcm.ri.repo.STREAM_FORGETS_UNBOUND_VERSIONS"; //$NON-NLS-1$
    public static final String IA_VERSION_KNOWS_PARENT = "com.ibm.rational.wvcm.ri.VERSION_KNOWS_PARENT"; //$NON-NLS-1$


    /**
     * Construct an activity proxy for the given location.
     * 
     * @param loc the location of the activity.
     * @return a new proxy for an activity at this Location.
     */
    public Activity activity(Location loc);

    /**
     * Construct a baseline proxy for the given location.
     * 
     * @param loc the location of the baseline.
     * @return a new proxy for a baseline at this Location.
     */
    public Baseline baseline(Location loc);

    /**
     * Construct a component proxy for the given location.
     * 
     * @param loc the location of the component.
     * @return a new proxy for a component at this Location.
     */
    public Component component(Location loc);

    /**
     * Construct a configuration proxy for the given location.
     * 
     * @param loc the location of the configuration.
     * @return a new proxy for a configuration at this Location.
     */
    public Configuration configuration(Location loc);

    /**
     * Construct a controllable folder proxy for the given location.
     * 
     * @param loc the location of the controllable folder.
     * @return a new proxy for a controllable folder at this Location.
     */
    public ControllableFolder controllableFolder(Location loc);

    /**
     * Construct a controllable resource proxy for the given location.
     * 
     * @param loc the location of the controllable resource.
     * @return a new proxy for a controllable resource at this Location.
     */
    public ControllableResource controllableResource(Location loc);

    /**
     * Construct a controllable symbolic link proxy for the given location.
     * 
     * @param loc the location of the controllable symbolic link.
     * @return a new proxy for a controllable symbolic link at this Location.
     */
    public ControllableSymbolicLink controllableSymbolicLink(Location loc);

    /**
     * Construct a folder version proxy for the given location.

     * @param loc the location of the folder version.
     * @return a new proxy for a folder version at this Location.
     */
    public FolderVersion folderVersion(Location loc);

    /**
     * Construct a stream proxy for the given location.

     * @param loc the location of the stream.
     * @return a new proxy for a stream at this Location.
     */
    public Stream stream(Location loc);

    /**
     * Construct a task proxy for the given location.

     * @param loc the location of the task.
     * @return a new proxy for a task at this Location.
     */
    public Task task(Location loc);

    /**
     * Construct a version proxy for the given location.
     * 
     * @param loc the location of the version.
     * @return a new proxy for a version at this Location.
     */
    public Version version(Location loc);

    /**
     * Construct a version history proxy for the given location.
     * 
     * @param loc the location of the version history.
     * @return a new proxy for a version history at this Location.
     */
    public VersionHistory versionHistory(Location loc);

    /**
     * Construct a workspace proxy for the given location.

     * @param loc the location of the workspace.
     * @return a new proxy for a workspace at this Location.
     */
    public Workspace workspace(Location loc);

}
